@@ -60,7 +60,9 @@ canvas_mosaic <- function(colors,
   sequence <- seq(0, resolution, by = 1)
   canvas <- expand.grid(sequence, sequence)
   colnames(canvas) <- c("x", "y")
-  z <- predict(fit, newdata = canvas)
+  suppressWarnings({
+    z <- predict(fit, newdata = canvas)
+  })
   full_canvas <- data.frame(x = canvas[["x"]], y = canvas[["y"]], z = z)
   artwork <- ggplot2::ggplot(data = full_canvas, mapping = ggplot2::aes(x = x, y = y, fill = z)) +
     ggplot2::geom_raster(interpolate = TRUE) +
